[![Build Status](https://travis-ci.org/anti-social/elasticmagic.svg)](https://travis-ci.org/anti-social/elasticmagic)
[![codecov](https://codecov.io/gh/anti-social/elasticmagic/branch/master/graph/badge.svg)](https://codecov.io/gh/anti-social/elasticmagic)
[![docs](https://readthedocs.org/projects/elasticmagic/badge/?version=latest )](https://elasticmagic.readthedocs.io/en/latest/)

elasticmagic
============

Python DSL for Elasticsearch

Caution: do not use it, this is a very alpha
